summaryrefslogtreecommitdiff
path: root/cmd/podman/registry/registry.go
diff options
context:
space:
mode:
authorOpenShift Merge Robot <openshift-merge-robot@users.noreply.github.com>2020-05-08 19:27:09 +0200
committerGitHub <noreply@github.com>2020-05-08 19:27:09 +0200
commitf07a0d937fd575248f404f784d0e3d41a59b7419 (patch)
tree8564a6a9f1a0653e3c04974ba69d26540f87010f /cmd/podman/registry/registry.go
parent13db0f2b61b17e6f959fff832b40270352cd54da (diff)
parent69f62a1a9c09818f888247fec96344cae6e4b6ff (diff)
downloadpodman-f07a0d937fd575248f404f784d0e3d41a59b7419.tar.gz
podman-f07a0d937fd575248f404f784d0e3d41a59b7419.tar.bz2
podman-f07a0d937fd575248f404f784d0e3d41a59b7419.zip
Merge pull request #6143 from rhatdan/remote
default to tunnel without ABISupport tag
Diffstat (limited to 'cmd/podman/registry/registry.go')
-rw-r--r--cmd/podman/registry/registry.go20
1 files changed, 18 insertions, 2 deletions
diff --git a/cmd/podman/registry/registry.go b/cmd/podman/registry/registry.go
index 69e2babfc..71ee2bed0 100644
--- a/cmd/podman/registry/registry.go
+++ b/cmd/podman/registry/registry.go
@@ -2,14 +2,18 @@ package registry
import (
"context"
+ "path/filepath"
"github.com/containers/libpod/pkg/domain/entities"
"github.com/containers/libpod/pkg/domain/infra"
+ "github.com/containers/libpod/pkg/rootless"
+ "github.com/containers/libpod/pkg/util"
+ "github.com/sirupsen/logrus"
"github.com/spf13/cobra"
)
-// DefaultAPIAddress is the default address of the REST socket
-const DefaultAPIAddress = "unix:/run/podman/podman.sock"
+// DefaultRootAPIAddress is the default address of the REST socket
+const DefaultRootAPIAddress = "unix:/run/podman/podman.sock"
// DefaultVarlinkAddress is the default address of the varlink socket
const DefaultVarlinkAddress = "unix:/run/podman/io.podman"
@@ -98,3 +102,15 @@ func GetContextWithOptions() context.Context {
func GetContext() context.Context {
return Context()
}
+
+func DefaultAPIAddress() string {
+ if rootless.IsRootless() {
+ xdg, err := util.GetRuntimeDir()
+ if err != nil {
+ logrus.Warnf("Failed to get rootless runtime dir for DefaultAPIAddress: %s", err)
+ return DefaultRootAPIAddress
+ }
+ return "unix:" + filepath.Join(xdg, "podman", "podman.sock")
+ }
+ return DefaultRootAPIAddress
+}